@@ -42,7 +42,7 @@ class GSCNodeFunctionReceiverSocket:
             connectURL = self.gsdbs.credentials["signalserver"]
 
         self.sio.connect(
-            f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}{self.gsdbs.credentials["cnode"]}&global=true&poolsize={self.poolsize}')
+            f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}&global=true&poolsize={self.poolsize}')
         self.sio.wait()
 
     def sendcnodefunctionResult(self, id, msg):
@@ -94,7 +94,7 @@ class GSCNodeFunctionCallerSocket:
             connectURL = self.gsdbs.credentials["signalserver"]
 
         self.sio.connect(
-            f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}{self.gsdbs.credentials["cnode"]}&caller=true')
+            f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}&caller=true')
         self.sio.wait()
 
 
