@@ -246,6 +246,18 @@ def channel_send(logger, channel, message):
     channel.send(message)
 
 
+def syncify_async_function(async_func):
+    loop = asyncio.get_event_loop()
+
+    def sync_func(*args, **kwargs):
+        if not loop.is_running():
+            loop.run_until_complete(asyncio.sleep(0))
+
+        return loop.run_until_complete(async_func(*args, **kwargs))
+
+    return sync_func
+
+
 class GSPeerConnectionBroadcasterPiSocketv2:
 
     def getPiH264Relay(self, id):
@@ -377,19 +389,10 @@ class GSPeerConnectionBroadcasterPiSocketv2:
                 offer = await pc.createOffer()
                 await pc.setLocalDescription(offer)
 
-
             # loop.run_until_complete( pc.setLocalDescription(awaitpc.createOffer()))
             # asyncio.run(create_and_set_local_description(pc))
-            loop = asyncio.new_event_loop()
-            asyncio.set_event_loop(loop)
-
-            # Call the function synchronously using the event loop
-            loop.run_until_complete(create_and_set_local_description(pc))
-
-            # Close the event loop
-            loop.close()
-
 
+            syncify_async_function(create_and_set_local_description(pc))
 
             self.sio.emit("watcher", {"target": description,
                                       "id": id,
@@ -406,28 +409,15 @@ class GSPeerConnectionBroadcasterPiSocketv2:
                         description = ast.literal_eval(description)
                     desc = type('new_dict', (object,), description)
                     answer = RTCSessionDescription(sdp=description["sdp"], type=description["type"])
-                    loop = asyncio.new_event_loop()
-                    asyncio.set_event_loop(loop)
-
-                    # Call the function synchronously using the event loop
-                    loop.run_until_complete(self.peerConnections[id].setRemoteDescription(answer))
-
-                    # Close the event loop
-                    loop.close()
 
+                    syncify_async_function(self.peerConnections[id].setRemoteDescription(answer))
 
         @self.sio.event
         def disconnectBroadcaster(id, desc):
             if id in self.peerConnections:
                 self._logger.info("Disconnected Peer")
 
-                loop = asyncio.new_event_loop()
-                asyncio.set_event_loop(loop)
-
-                loop.run_until_complete(asyncio.run(self.peerConnections[id].close()))
-
-                loop.close()
-
+                syncify_async_function(asyncio.run(self.peerConnections[id].close()))
 
                 self.peerConnections.pop(id, None)
 
